==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeTypeInfo.h <==
// class gnu.xml.libxmlj.dom.GnomeTypeInfo

// class file dependencies
// @dep_class 1bcac6f5b0ee47e0 gnu_xml_libxmlj_dom_GnomeTypeInfo
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeTypeInfo_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeTypeInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$refs	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtable	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtype	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method$getTypeName$271437c0e580ba86(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method$getTypeNamespace$33bd38b937baef29(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *);
extern jboolean _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method$isDerivedFrom$f18f534310af797e(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method_info$getTypeName$271437c0e580ba86;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method_info$getTypeNamespace$33bd38b937baef29;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method_info$isDerivedFrom$f18f534310af797e;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vmethods {
	struct _jc_java_lang_String$object	*(*getTypeName$271437c0e580ba86)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *);
	struct _jc_java_lang_String$object	*(*getTypeNamespace$33bd38b937baef29)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *);
	jboolean	(*isDerivedFrom$f18f534310af797e)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vmethods	gnu_xml_libxmlj_dom_GnomeTypeInfo;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_refs {
	struct _jc_java_lang_Object$object	*id;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_refs	gnu_xml_libxmlj_dom_GnomeTypeInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeTypeInfo;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object {
	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtype _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeTypeInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeTypeInfo_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeTypeInfo.h <==
// class gnu.xml.libxmlj.dom.GnomeTypeInfo

// class file dependencies
// @dep_class 1bcac6f5b0ee47e0 gnu_xml_libxmlj_dom_GnomeTypeInfo
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeTypeInfo_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeTypeInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$refs	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtable	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtype	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method$getTypeName$271437c0e580ba86(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method$getTypeNamespace$33bd38b937baef29(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method$isDerivedFrom$f18f534310af797e(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method_info$getTypeName$271437c0e580ba86;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method_info$getTypeNamespace$33bd38b937baef29;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$method_info$isDerivedFrom$f18f534310af797e;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vmethods {
	struct _jc_java_lang_String$object	*(*getTypeName$271437c0e580ba86)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getTypeNamespace$33bd38b937baef29)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *) _JC_JCNI_ATTR;
	jboolean	(*isDerivedFrom$f18f534310af797e)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vmethods	gnu_xml_libxmlj_dom_GnomeTypeInfo;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_refs {
	struct _jc_java_lang_Object$object	*id;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_refs	gnu_xml_libxmlj_dom_GnomeTypeInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeTypeInfo;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$object {
	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$vtype _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeTypeInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeTypeInfo$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeTypeInfo_H_ */
